You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by el...@apache.org on 2010/06/15 23:15:06 UTC

svn commit: r955056 [2/5] - in /directory: apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/ apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/event/ apacheds/trunk/core-api/src/main/java/org/apache/directory/...

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -115,10 +115,10 @@ public class SchemaSynchronizer implemen
      * Depending in the existence of this attribute in the previous entry, we will
      * have to update the entry or not.
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade ) throws LdapException
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade ) throws LdapException
     {
-        Entry entry = opContext.getEntry();
-        List<Modification> mods = opContext.getModItems(); 
+        Entry entry = modifyContext.getEntry();
+        List<Modification> mods = modifyContext.getModItems(); 
         boolean hasModification = SCHEMA_UNCHANGED;
         
         // Check if the entry has a m-disabled attribute 
@@ -134,11 +134,11 @@ public class SchemaSynchronizer implemen
             ModificationOperation modification = disabledModification.getOperation();
             EntryAttribute attribute = disabledModification.getAttribute();
             
-            hasModification = modifyDisable( opContext, modification, attribute, disabledInEntry );
+            hasModification = modifyDisable( modifyContext, modification, attribute, disabledInEntry );
         }
         else if ( disabledInEntry != null )
         {
-            hasModification = modifyDisable( opContext, ModificationOperation.REMOVE_ATTRIBUTE, null, disabledInEntry );
+            hasModification = modifyDisable( modifyContext, ModificationOperation.REMOVE_ATTRIBUTE, null, disabledInEntry );
         }
             
         
@@ -391,10 +391,10 @@ public class SchemaSynchronizer implemen
      * +-------+-------+-------------------+--------------------+--------------------+
      * </pre>
      */
-    private boolean modifyDisable( ModifyOperationContext opContext, ModificationOperation modOp, 
+    private boolean modifyDisable( ModifyOperationContext modifyContext, ModificationOperation modOp, 
         EntryAttribute disabledInMods, EntryAttribute disabledInEntry ) throws LdapException
     {
-        DN name = opContext.getDn();
+        DN name = modifyContext.getDn();
         
         switch ( modOp )
         {

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxCheckerSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -68,11 +68,11 @@ public class SyntaxCheckerSynchronizer e
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String schemaName = getSchemaName( name );
         String oid = getOid( entry );
         SyntaxChecker syntaxChecker = factory.getSyntaxChecker( schemaManager, targetEntry, schemaManager

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SyntaxSynchronizer.java Tue Jun 15 21:15:04 2010
@@ -72,11 +72,11 @@ public class SyntaxSynchronizer extends 
     /**
      * {@inheritDoc}
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean cascade )
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean cascade )
         throws LdapException
     {
-        DN name = opContext.getDn();
-        Entry entry = opContext.getEntry();
+        DN name = modifyContext.getDn();
+        Entry entry = modifyContext.getEntry();
         String oid = getOid( entry );
         LdapSyntax syntax = factory.getSyntax( schemaManager, targetEntry, schemaManager.getRegistries(),
             getSchemaName( name ) );

Modified: directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockCoreSession.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockCoreSession.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockCoreSession.java (original)
+++ directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockCoreSession.java Tue Jun 15 21:15:04 2010
@@ -136,12 +136,12 @@ public class MockCoreSession implements 
      */
     public void add( Entry entry, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, entry );
+        AddOperationContext addContext = new AddOperationContext( this, entry );
 
-        opContext.setLogChange( log );
+        addContext.setLogChange( log );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
+        operationManager.add( addContext );
     }
 
 
@@ -150,13 +150,13 @@ public class MockCoreSession implements 
      */
     public void add( Entry entry, boolean ignoreReferral, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, entry );
+        AddOperationContext addContext = new AddOperationContext( this, entry );
 
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        addContext.setLogChange( log );
+        setReferralHandling( addContext, ignoreReferral );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
+        operationManager.add( addContext );
     }
 
 
@@ -174,13 +174,13 @@ public class MockCoreSession implements 
      */
     public void add( InternalAddRequest addRequest, LogChange log ) throws LdapException
     {
-        AddOperationContext opContext = new AddOperationContext( this, addRequest );
+        AddOperationContext addContext = new AddOperationContext( this, addRequest );
 
-        opContext.setLogChange( log );
+        addContext.setLogChange( log );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.add( opContext );
-        addRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.add( addContext );
+        addRequest.getResultResponse().addAll( addContext.getResponseControls() );
     }
 
     
@@ -243,14 +243,14 @@ public class MockCoreSession implements 
      */
     public boolean compare( DN dn, String oid, Object value, boolean ignoreReferral ) throws LdapException
     {
-        CompareOperationContext opContext =  
+        CompareOperationContext compareContext =  
                 new CompareOperationContext( this, dn, oid, 
                     convertToValue( oid, value ) );
         
-        setReferralHandling( opContext, ignoreReferral );
+        setReferralHandling( compareContext, ignoreReferral );
         
         OperationManager operationManager = directoryService.getOperationManager();
-        return operationManager.compare( opContext );
+        return operationManager.compare( compareContext );
     }
 
 
@@ -268,12 +268,12 @@ public class MockCoreSession implements 
      */
     public void delete( DN dn, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, dn );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, dn );
 
-        opContext.setLogChange( log );
+        deleteContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
+        operationManager.delete( deleteContext );
     }
 
 
@@ -291,13 +291,13 @@ public class MockCoreSession implements 
      */
     public void delete( DN dn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, dn );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, dn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        deleteContext.setLogChange( log );
+        setReferralHandling( deleteContext, ignoreReferral );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
+        operationManager.delete( deleteContext );
     }
 
 
@@ -445,10 +445,10 @@ public class MockCoreSession implements 
     {
         OperationManager operationManager = directoryService.getOperationManager();
         
-        ListOperationContext listOperationContext = new ListOperationContext( this, dn, returningAttributes );
-        listOperationContext.setAliasDerefMode( aliasDerefMode );
+        ListOperationContext listContext = new ListOperationContext( this, dn, returningAttributes );
+        listContext.setAliasDerefMode( aliasDerefMode );
         
-        return operationManager.list( listOperationContext );
+        return operationManager.list( listContext );
     }
 
 
@@ -460,12 +460,12 @@ public class MockCoreSession implements 
     {
         OperationManager operationManager = directoryService.getOperationManager();
 
-        ListOperationContext listOperationContext = new ListOperationContext( this, dn, returningAttributes );
-        listOperationContext.setSizeLimit( sizeLimit );
-        listOperationContext.setTimeLimit( timeLimit );
-        listOperationContext.setAliasDerefMode( aliasDerefMode );
+        ListOperationContext listContext = new ListOperationContext( this, dn, returningAttributes );
+        listContext.setSizeLimit( sizeLimit );
+        listContext.setTimeLimit( timeLimit );
+        listContext.setAliasDerefMode( aliasDerefMode );
      
-        return operationManager.list( listOperationContext );
+        return operationManager.list( listContext );
     }
 
 
@@ -516,12 +516,12 @@ public class MockCoreSession implements 
             serverModifications.add( new DefaultModification( directoryService.getSchemaManager(), mod ) );
         }
         
-        ModifyOperationContext opContext = new ModifyOperationContext( this, dn, serverModifications );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, dn, serverModifications );
 
-        opContext.setLogChange( log );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
+        operationManager.modify( modifyContext );
     }
 
 
@@ -551,13 +551,13 @@ public class MockCoreSession implements 
             serverModifications.add( new DefaultModification( directoryService.getSchemaManager(), mod ) );
         }
 
-        ModifyOperationContext opContext = new ModifyOperationContext( this, dn, serverModifications );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, dn, serverModifications );
         
-        setReferralHandling( opContext, ignoreReferral );
-        opContext.setLogChange( log );
+        setReferralHandling( modifyContext, ignoreReferral );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
+        operationManager.modify( modifyContext );
     }
 
 
@@ -575,12 +575,12 @@ public class MockCoreSession implements 
      */
     public void move( DN dn, DN newParent, LogChange log ) throws LdapException
     {
-        MoveOperationContext opContext = new MoveOperationContext( this, dn, newParent );
+        MoveOperationContext moveContext = new MoveOperationContext( this, dn, newParent );
         
-        opContext.setLogChange( log );
+        moveContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.move( opContext );
+        operationManager.move( moveContext );
     }
 
 
@@ -599,12 +599,12 @@ public class MockCoreSession implements 
     public void move( DN dn, DN newParent, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        MoveOperationContext opContext = new MoveOperationContext( this, dn, newParent );
+        MoveOperationContext moveContext = new MoveOperationContext( this, dn, newParent );
         
-        setReferralHandling( opContext, ignoreReferral );
-        opContext.setLogChange( log );
+        setReferralHandling( moveContext, ignoreReferral );
+        moveContext.setLogChange( log );
 
-        operationManager.move( opContext );
+        operationManager.move( moveContext );
     }
 
 
@@ -622,13 +622,13 @@ public class MockCoreSession implements 
      */
     public void moveAndRename( DN dn, DN newParent, RDN newRdn, boolean deleteOldRdn, LogChange log ) throws LdapException
     {
-        MoveAndRenameOperationContext opContext = 
+        MoveAndRenameOperationContext moveAndRenameContext = 
             new MoveAndRenameOperationContext( this, dn, newParent, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
+        moveAndRenameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.moveAndRename( opContext );
+        operationManager.moveAndRename( moveAndRenameContext );
     }
 
 
@@ -647,12 +647,12 @@ public class MockCoreSession implements 
     public void moveAndRename( DN dn, DN newParent, RDN newRdn, boolean deleteOldRdn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        MoveAndRenameOperationContext opContext = new MoveAndRenameOperationContext( this, dn, newParent, newRdn, deleteOldRdn );
+        MoveAndRenameOperationContext moveAndRenameContext = new MoveAndRenameOperationContext( this, dn, newParent, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        moveAndRenameContext.setLogChange( log );
+        setReferralHandling( moveAndRenameContext, ignoreReferral );
 
-        operationManager.moveAndRename( opContext );
+        operationManager.moveAndRename( moveAndRenameContext );
     }
 
 
@@ -670,12 +670,12 @@ public class MockCoreSession implements 
      */
     public void rename( DN dn, RDN newRdn, boolean deleteOldRdn, LogChange log ) throws LdapException
     {
-        RenameOperationContext opContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
+        RenameOperationContext renameContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
+        renameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.rename( opContext );
+        operationManager.rename( renameContext );
     }
 
 
@@ -694,12 +694,12 @@ public class MockCoreSession implements 
     public void rename( DN dn, RDN newRdn, boolean deleteOldRdn, boolean ignoreReferral, LogChange log ) throws LdapException
     {
         OperationManager operationManager = directoryService.getOperationManager();
-        RenameOperationContext opContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
+        RenameOperationContext renameContext = new RenameOperationContext( this, dn, newRdn, deleteOldRdn );
         
-        opContext.setLogChange( log );
-        setReferralHandling( opContext, ignoreReferral );
+        renameContext.setLogChange( log );
+        setReferralHandling( renameContext, ignoreReferral );
 
-        operationManager.rename( opContext );
+        operationManager.rename( renameContext );
     }
 
 
@@ -729,12 +729,12 @@ public class MockCoreSession implements 
             throw new LdapInvalidSearchFilterException( pe.getMessage() );
         }
         
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, SearchScope.OBJECT, 
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, SearchScope.OBJECT, 
             filterNode, null );
-        searchOperationContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS );
-        setReferralHandling( searchOperationContext, ignoreReferrals );
+        searchContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS );
+        setReferralHandling( searchContext, ignoreReferrals );
 
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
     
 
@@ -746,11 +746,11 @@ public class MockCoreSession implements 
     {
         OperationManager operationManager = directoryService.getOperationManager();
         
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, scope, 
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, scope, 
             filter, returningAttributes );
-        searchOperationContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS );
+        searchContext.setAliasDerefMode( AliasDerefMode.DEREF_ALWAYS );
 
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
 
 
@@ -762,12 +762,12 @@ public class MockCoreSession implements 
     {
         OperationManager operationManager = directoryService.getOperationManager();
         
-        SearchOperationContext searchOperationContext = new SearchOperationContext( this, dn, scope, filter, returningAttributes );
-        searchOperationContext.setSizeLimit( sizeLimit );
-        searchOperationContext.setTimeLimit( timeLimit );
-        searchOperationContext.setAliasDerefMode( aliasDerefMode );
+        SearchOperationContext searchContext = new SearchOperationContext( this, dn, scope, filter, returningAttributes );
+        searchContext.setSizeLimit( sizeLimit );
+        searchContext.setTimeLimit( timeLimit );
+        searchContext.setAliasDerefMode( aliasDerefMode );
 
-        return operationManager.search( searchOperationContext );
+        return operationManager.search( searchContext );
     }
 
 
@@ -782,10 +782,10 @@ public class MockCoreSession implements 
      */
     public boolean compare( InternalCompareRequest compareRequest ) throws LdapException
     {
-        CompareOperationContext opContext = new CompareOperationContext( this, compareRequest );
+        CompareOperationContext compareContext = new CompareOperationContext( this, compareRequest );
         OperationManager operationManager = directoryService.getOperationManager();
-        boolean result = operationManager.compare( opContext );
-        compareRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        boolean result = operationManager.compare( compareContext );
+        compareRequest.getResultResponse().addAll( compareContext.getResponseControls() );
         return result;
     }
 
@@ -804,21 +804,21 @@ public class MockCoreSession implements 
      */
     public void delete( InternalDeleteRequest deleteRequest, LogChange log ) throws LdapException
     {
-        DeleteOperationContext opContext = new DeleteOperationContext( this, deleteRequest );
+        DeleteOperationContext deleteContext = new DeleteOperationContext( this, deleteRequest );
         
-        opContext.setLogChange( log );
+        deleteContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.delete( opContext );
-        deleteRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.delete( deleteContext );
+        deleteRequest.getResultResponse().addAll( deleteContext.getResponseControls() );
     }
 
 
     public boolean exists( DN dn ) throws LdapException
     {
-        EntryOperationContext opContext = new EntryOperationContext( this, dn );
+        EntryOperationContext hasEntryContext = new EntryOperationContext( this, dn );
         OperationManager operationManager = directoryService.getOperationManager();
-        return operationManager.hasEntry( opContext );
+        return operationManager.hasEntry( hasEntryContext );
     }
 
 
@@ -836,13 +836,13 @@ public class MockCoreSession implements 
      */
     public void modify( InternalModifyRequest modifyRequest, LogChange log ) throws LdapException
     {
-        ModifyOperationContext opContext = new ModifyOperationContext( this, modifyRequest );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( this, modifyRequest );
 
-        opContext.setLogChange( log );
+        modifyContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.modify( opContext );
-        modifyRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.modify( modifyContext );
+        modifyRequest.getResultResponse().addAll( modifyContext.getResponseControls() );
     }
 
 
@@ -860,13 +860,13 @@ public class MockCoreSession implements 
      */
     public void move( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        MoveOperationContext opContext = new MoveOperationContext( this, modifyDnRequest );
+        MoveOperationContext moveContext = new MoveOperationContext( this, modifyDnRequest );
         
-        opContext.setLogChange( log );
+        moveContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.move( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.move( moveContext );
+        modifyDnRequest.getResultResponse().addAll( moveContext.getResponseControls() );
     }
 
 
@@ -884,13 +884,13 @@ public class MockCoreSession implements 
      */
     public void moveAndRename( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        MoveAndRenameOperationContext opContext = new MoveAndRenameOperationContext( this, modifyDnRequest );
+        MoveAndRenameOperationContext moveAndRenameContext = new MoveAndRenameOperationContext( this, modifyDnRequest );
 
-        opContext.setLogChange( log );
+        moveAndRenameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.moveAndRename( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.moveAndRename( moveAndRenameContext );
+        modifyDnRequest.getResultResponse().addAll( moveAndRenameContext.getResponseControls() );
     }
 
 
@@ -908,22 +908,22 @@ public class MockCoreSession implements 
      */
     public void rename( InternalModifyDnRequest modifyDnRequest, LogChange log ) throws LdapException
     {
-        RenameOperationContext opContext = new RenameOperationContext( this, modifyDnRequest );
+        RenameOperationContext renameContext = new RenameOperationContext( this, modifyDnRequest );
 
-        opContext.setLogChange( log );
+        renameContext.setLogChange( log );
 
         OperationManager operationManager = directoryService.getOperationManager();
-        operationManager.rename( opContext );
-        modifyDnRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        operationManager.rename( renameContext );
+        modifyDnRequest.getResultResponse().addAll( renameContext.getResponseControls() );
     }
 
 
     public EntryFilteringCursor search( InternalSearchRequest searchRequest ) throws LdapException
     {
-        SearchOperationContext opContext = new SearchOperationContext( this, searchRequest );
+        SearchOperationContext searchContext = new SearchOperationContext( this, searchRequest );
         OperationManager operationManager = directoryService.getOperationManager();
-        EntryFilteringCursor cursor = operationManager.search( opContext );
-        searchRequest.getResultResponse().addAll( opContext.getResponseControls() );
+        EntryFilteringCursor cursor = operationManager.search( searchContext );
+        searchRequest.getResultResponse().addAll( searchContext.getResponseControls() );
         
         return cursor;
     }

Modified: directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockInterceptor.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockInterceptor.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockInterceptor.java (original)
+++ directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockInterceptor.java Tue Jun 15 21:15:04 2010
@@ -78,11 +78,11 @@ public class MockInterceptor implements 
     }
 
 
-    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext opContext )
+    public Entry getRootDSE( NextInterceptor next, GetRootDSEOperationContext getRootDseContext )
         throws LdapException
     {
         interceptors.add( this );
-        return next.getRootDSE( opContext );
+        return next.getRootDSE( getRootDseContext );
     }
 
 
@@ -93,10 +93,10 @@ public class MockInterceptor implements 
     }
 
 
-    public void delete( NextInterceptor next, DeleteOperationContext opContext ) throws LdapException
+    public void delete( NextInterceptor next, DeleteOperationContext deleteContext ) throws LdapException
     {
         interceptors.add( this );
-        next.delete( opContext );
+        next.delete( deleteContext );
     }
 
 
@@ -107,45 +107,45 @@ public class MockInterceptor implements 
     }
 
 
-    public void modify( NextInterceptor next, ModifyOperationContext opContext ) throws LdapException
+    public void modify( NextInterceptor next, ModifyOperationContext modifyContext ) throws LdapException
     {
         interceptors.add( this );
-        next.modify( opContext );
+        next.modify( modifyContext );
     }
 
 
-    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( NextInterceptor next, ListOperationContext listContext ) throws LdapException
     {
         interceptors.add( this );
-        return next.list( opContext );
+        return next.list( listContext );
     }
 
 
-    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( NextInterceptor next, SearchOperationContext searchContext ) throws LdapException
     {
         interceptors.add( this );
-        return next.search( opContext );
+        return next.search( searchContext );
     }
 
 
-    public Entry lookup( NextInterceptor next, LookupOperationContext opContext ) throws LdapException
+    public Entry lookup( NextInterceptor next, LookupOperationContext lookupContext ) throws LdapException
     {
         interceptors.add( this );
-        return next.lookup( opContext );
+        return next.lookup( lookupContext );
     }
 
 
-    public boolean hasEntry( NextInterceptor next, EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( NextInterceptor next, EntryOperationContext hasEntryContext ) throws LdapException
     {
         interceptors.add( this );
-        return next.hasEntry( opContext );
+        return next.hasEntry( hasEntryContext );
     }
 
 
-    public void rename( NextInterceptor next, RenameOperationContext opContext ) throws LdapException
+    public void rename( NextInterceptor next, RenameOperationContext renameContext ) throws LdapException
     {
         interceptors.add( this );
-        next.rename( opContext );
+        next.rename( renameContext );
     }
 
 
@@ -163,17 +163,17 @@ public class MockInterceptor implements 
     }
 
 
-    public void bind( NextInterceptor next, BindOperationContext opContext ) throws LdapException
+    public void bind( NextInterceptor next, BindOperationContext bindContext ) throws LdapException
     {
         interceptors.add( this );
-        next.bind( opContext );
+        next.bind( bindContext );
     }
 
 
-    public void unbind( NextInterceptor next, UnbindOperationContext opContext ) throws LdapException
+    public void unbind( NextInterceptor next, UnbindOperationContext unbindContext ) throws LdapException
     {
         interceptors.add( this );
-        next.unbind( opContext );
+        next.unbind( unbindContext );
     }
 
 

Modified: directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperation.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperation.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperation.java (original)
+++ directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperation.java Tue Jun 15 21:15:04 2010
@@ -49,16 +49,16 @@ public class MockOperation implements Op
     }
 
 
-    public EntryFilteringCursor search( SearchOperationContext opContext )
+    public EntryFilteringCursor search( SearchOperationContext searchContext )
         throws LdapException
     {
-        return new BaseEntryFilteringCursor( new MockCursor( count ), opContext );
+        return new BaseEntryFilteringCursor( new MockCursor( count ), searchContext );
     }
 
 
-    public EntryFilteringCursor search( SearchOperationContext opContext, Collection<String> bypass ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext, Collection<String> bypass ) throws LdapException
     {
-        return new BaseEntryFilteringCursor( new MockCursor( count ), opContext );
+        return new BaseEntryFilteringCursor( new MockCursor( count ), searchContext );
     }
 
 

Modified: directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperationManager.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperationManager.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperationManager.java (original)
+++ directory/apacheds/trunk/core-api/src/test/java/org/apache/directory/server/core/MockOperationManager.java Tue Jun 15 21:15:04 2010
@@ -48,51 +48,51 @@ public class MockOperationManager implem
         this.count = count;
     }
     
-    public void add( AddOperationContext opContext ) throws LdapException
+    public void add( AddOperationContext addContext ) throws LdapException
     {
     }
 
     
-    public void bind( BindOperationContext opContext ) throws LdapException
+    public void bind( BindOperationContext bindContext ) throws LdapException
     {
     }
 
     
-    public boolean compare( CompareOperationContext opContext ) throws LdapException
+    public boolean compare( CompareOperationContext compareContext ) throws LdapException
     {
         return false;
     }
 
 
-    public void delete( DeleteOperationContext opContext ) throws LdapException
+    public void delete( DeleteOperationContext deleteContext ) throws LdapException
     {
     }
 
-    public Entry getRootDSE( GetRootDSEOperationContext opContext ) throws LdapException
+    public Entry getRootDSE( GetRootDSEOperationContext getRootDseContext ) throws LdapException
     {
         return null;
     }
 
-    public boolean hasEntry( EntryOperationContext opContext ) throws LdapException
+    public boolean hasEntry( EntryOperationContext hasEntryContext ) throws LdapException
     {
         return false;
     }
 
-    public EntryFilteringCursor list( ListOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor list( ListOperationContext listContext ) throws LdapException
     {
         return null;
     }
 
-    public ClonedServerEntry lookup( LookupOperationContext opContext ) throws LdapException
+    public ClonedServerEntry lookup( LookupOperationContext lookupContext ) throws LdapException
     {
         return null;
     }
 
-    public void modify( ModifyOperationContext opContext ) throws LdapException
+    public void modify( ModifyOperationContext modifyContext ) throws LdapException
     {
     }
 
-    public void move( MoveOperationContext opContext ) throws LdapException
+    public void move( MoveOperationContext moveContext ) throws LdapException
     {
     }
 
@@ -100,19 +100,19 @@ public class MockOperationManager implem
     {
     }
 
-    public void rename( RenameOperationContext opContext ) throws LdapException
+    public void rename( RenameOperationContext renameContext ) throws LdapException
     {
     }
 
-    public EntryFilteringCursor search( SearchOperationContext opContext ) throws LdapException
+    public EntryFilteringCursor search( SearchOperationContext searchContext ) throws LdapException
     {
         MockCursor cursor = new MockCursor( count );
-        cursor.setSchemaManager( opContext.getSession().getDirectoryService().getSchemaManager() );
-        return new BaseEntryFilteringCursor( cursor, opContext );
+        cursor.setSchemaManager( searchContext.getSession().getDirectoryService().getSchemaManager() );
+        return new BaseEntryFilteringCursor( cursor, searchContext );
     }
 
 
-    public void unbind( UnbindOperationContext opContext ) throws LdapException
+    public void unbind( UnbindOperationContext unbindContext ) throws LdapException
     {
     }
 }

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/getRootDse/GetRootDsePerfIT.java Tue Jun 15 21:15:04 2010
@@ -43,8 +43,8 @@ public class GetRootDsePerfIT extends Ab
     @Test
     public void testPerfGetRootDSE() throws Exception
     {
-        GetRootDSEOperationContext opContext = new GetRootDSEOperationContext( service.getAdminSession() );
-        Entry rootDSE = service.getOperationManager().getRootDSE( opContext );
+        GetRootDSEOperationContext getRootDseContext = new GetRootDSEOperationContext( service.getAdminSession() );
+        Entry rootDSE = service.getOperationManager().getRootDSE( getRootDseContext );
 
         assertNotNull( rootDSE );
         int nbIterations = 150000;
@@ -68,7 +68,7 @@ public class GetRootDsePerfIT extends Ab
                 t00 = System.currentTimeMillis();
             }
 
-            rootDSE = service.getOperationManager().getRootDSE( opContext );
+            rootDSE = service.getOperationManager().getRootDSE( getRootDseContext );
         }
         
         long t1 = System.currentTimeMillis();

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/hasEntry/hasEntryPerfIT.java Tue Jun 15 21:15:04 2010
@@ -44,8 +44,8 @@ public class hasEntryPerfIT extends Abst
     public void testPerfHasEntry() throws Exception
     {
         DN adminDn = new DN( "uid=admin, ou=system" );
-        EntryOperationContext opContext = new EntryOperationContext( service.getAdminSession(), adminDn );
-        boolean hasEntry = service.getOperationManager().hasEntry( opContext );
+        EntryOperationContext hasEntryContext = new EntryOperationContext( service.getAdminSession(), adminDn );
+        boolean hasEntry = service.getOperationManager().hasEntry( hasEntryContext );
 
         assertTrue( hasEntry );
         int nbIterations = 150000;
@@ -69,7 +69,7 @@ public class hasEntryPerfIT extends Abst
                 t00 = System.currentTimeMillis();
             }
 
-            hasEntry = service.getOperationManager().hasEntry( opContext );
+            hasEntry = service.getOperationManager().hasEntry( hasEntryContext );
         }
         
         long t1 = System.currentTimeMillis();

Modified: directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/list/ListPerfTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/list/ListPerfTest.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/list/ListPerfTest.java (original)
+++ directory/apacheds/trunk/core-integ/src/test/java/org/apache/directory/server/core/operations/list/ListPerfTest.java Tue Jun 15 21:15:04 2010
@@ -47,8 +47,8 @@ public class ListPerfTest extends Abstra
     @Test
     public void testPerfList() throws Exception
     {
-        ListOperationContext opContext = new ListOperationContext( service.getAdminSession(), new DN( "ou=system" ) );
-        EntryFilteringCursor cursor = service.getOperationManager().list( opContext );
+        ListOperationContext listContext = new ListOperationContext( service.getAdminSession(), new DN( "ou=system" ) );
+        EntryFilteringCursor cursor = service.getOperationManager().list( listContext );
 
         assertNotNull( cursor );
         int nb = 0;
@@ -87,7 +87,7 @@ public class ListPerfTest extends Abstra
             }
 
             nb = 0;
-            cursor = service.getOperationManager().list( opContext );
+            cursor = service.getOperationManager().list( listContext );
 
             while ( cursor.next() )
             {

Modified: directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/EventListenerAdapter.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/EventListenerAdapter.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/EventListenerAdapter.java (original)
+++ directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/EventListenerAdapter.java Tue Jun 15 21:15:04 2010
@@ -103,14 +103,14 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryAdded(org.apache.directory.server.core.interceptor.context.AddOperationContext)
      */
-    public void entryAdded( AddOperationContext opContext )
+    public void entryAdded( AddOperationContext addContext )
     {
         try
         {
-            Binding binding = new Binding( opContext.getDn().getName(), 
-                ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
+            Binding binding = new Binding( addContext.getDn().getName(), 
+                ServerEntryUtils.toBasicAttributes( addContext.getEntry() ), false );
             NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_ADDED, 
-                binding, null, opContext );
+                binding, null, addContext );
 
             if ( listener instanceof NamespaceChangeListener )
             {
@@ -127,16 +127,16 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryDeleted(org.apache.directory.server.core.interceptor.context.DeleteOperationContext)
      */
-    public void entryDeleted( DeleteOperationContext opContext )
+    public void entryDeleted( DeleteOperationContext deleteContext )
     {
         try
         {
             if ( listener instanceof NamespaceChangeListener )
             {
-                Binding binding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
+                Binding binding = new Binding( deleteContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( deleteContext.getEntry() ), false );
                 NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_REMOVED, null, 
-                    binding, opContext );
+                    binding, deleteContext );
                 ( ( NamespaceChangeListener ) listener ).objectAdded( evt );
             }
         }
@@ -150,16 +150,16 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryModified(org.apache.directory.server.core.interceptor.context.ModifyOperationContext)
      */
-    public void entryModified( ModifyOperationContext opContext )
+    public void entryModified( ModifyOperationContext modifyContext )
     {
         try
         {
-            Binding newBinding = new Binding( opContext.getDn().getName(), 
-                ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
-            Binding oldBinding = new Binding( opContext.getDn().getName(), 
-                ServerEntryUtils.toBasicAttributes( opContext.getEntry().getOriginalEntry() ),  false );
+            Binding newBinding = new Binding( modifyContext.getDn().getName(), 
+                ServerEntryUtils.toBasicAttributes( modifyContext.getEntry() ), false );
+            Binding oldBinding = new Binding( modifyContext.getDn().getName(), 
+                ServerEntryUtils.toBasicAttributes( modifyContext.getEntry().getOriginalEntry() ),  false );
             NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_CHANGED, 
-                newBinding, oldBinding, opContext );
+                newBinding, oldBinding, modifyContext );
 
             if ( listener instanceof ObjectChangeListener )
             {
@@ -176,18 +176,18 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryMoved(org.apache.directory.server.core.interceptor.context.MoveOperationContext)
      */
-    public void entryMoved( MoveOperationContext opContext )
+    public void entryMoved( MoveOperationContext moveContext )
     {
         try
         {
             if ( listener instanceof NamespaceChangeListener )
             {
-                Binding newBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
-                Binding oldBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry().getOriginalEntry() ), false );
+                Binding newBinding = new Binding( moveContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( moveContext.getEntry() ), false );
+                Binding oldBinding = new Binding( moveContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( moveContext.getEntry().getOriginalEntry() ), false );
                 NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_RENAMED, 
-                    newBinding, oldBinding, opContext );
+                    newBinding, oldBinding, moveContext );
                 ( ( NamespaceChangeListener ) listener ).objectRenamed( evt );
             }
         }
@@ -201,18 +201,18 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryMovedAndRenamed(org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext)
      */
-    public void entryMovedAndRenamed( MoveAndRenameOperationContext opContext )
+    public void entryMovedAndRenamed( MoveAndRenameOperationContext moveAndRenameContext )
     {
         try
         {
             if ( listener instanceof NamespaceChangeListener )
             {
-                Binding newBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
-                Binding oldBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry().getOriginalEntry() ), false );
+                Binding newBinding = new Binding( moveAndRenameContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( moveAndRenameContext.getEntry() ), false );
+                Binding oldBinding = new Binding( moveAndRenameContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( moveAndRenameContext.getEntry().getOriginalEntry() ), false );
                 NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_RENAMED, 
-                    newBinding, oldBinding, opContext );
+                    newBinding, oldBinding, moveAndRenameContext );
                 ( ( NamespaceChangeListener ) listener ).objectRenamed( evt );
             }
         }
@@ -226,16 +226,16 @@ public class EventListenerAdapter implem
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.event.DirectoryListener#entryRenamed(org.apache.directory.server.core.interceptor.context.RenameOperationContext)
      */
-    public void entryRenamed( RenameOperationContext opContext )
+    public void entryRenamed( RenameOperationContext renameContext )
     {
         try
         {
             if ( listener instanceof NamespaceChangeListener )
             {
-                Binding newBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry() ), false );
-                Binding oldBinding = new Binding( opContext.getDn().getName(), 
-                    ServerEntryUtils.toBasicAttributes( opContext.getEntry().getOriginalEntry() ), false );
+                Binding newBinding = new Binding( renameContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( renameContext.getEntry() ), false );
+                Binding oldBinding = new Binding( renameContext.getDn().getName(), 
+                    ServerEntryUtils.toBasicAttributes( renameContext.getEntry().getOriginalEntry() ), false );
                 NamingEvent evt = new NamingEvent( source, NamingEvent.OBJECT_RENAMED, 
                     newBinding, oldBinding, null );
                 ( ( NamespaceChangeListener ) listener ).objectRenamed( evt );

Modified: directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java (original)
+++ directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/RegistrySynchronizerAdaptor.java Tue Jun 15 21:15:04 2010
@@ -149,12 +149,12 @@ public class RegistrySynchronizerAdaptor
     /**
      * Add a new SchemaObject or a new Schema in the Schema partition.
      *
      * @param opContext The Add context, containing the entry to be added
      * @throws Exception If the addition failed 
      */
-    public void add( AddOperationContext opContext ) throws LdapException
+    public void add( AddOperationContext addContext ) throws LdapException
     {
-        EntryAttribute oc = opContext.getEntry().get( objectClassAT );
+        EntryAttribute oc = addContext.getEntry().get( objectClassAT );
         
         // First check if we are adding a schemaObject
         for ( Value<?> value:oc )
@@ -167,7 +167,7 @@ public class RegistrySynchronizerAdaptor
                 // This is one of the eleven SchemaObject :
                 // AT, C, DCR, DSR, MR, MRU, NF, N, OC, S, SC
                 RegistrySynchronizer synchronizer = objectClass2synchronizerMap.get( oid );
-                Entry entry = opContext.getEntry();
+                Entry entry = addContext.getEntry();
                 synchronizer.add( entry );
                 return;
             }
@@ -177,7 +177,7 @@ public class RegistrySynchronizerAdaptor
         // e.g. ou=my custom schema,ou=schema
         if ( oc.contains( MetaSchemaConstants.META_SCHEMA_OC ) )
         {
-            Entry entry = opContext.getEntry();
+            Entry entry = addContext.getEntry();
             schemaSynchronizer.add( entry );
             return;
         }
@@ -186,14 +186,14 @@ public class RegistrySynchronizerAdaptor
         // e.g. ou=attributeTypes,ou=my custom schema,ou=schema
         if ( oc.contains( SchemaConstants.ORGANIZATIONAL_UNIT_OC ) )
         {
-            if ( opContext.getDn().size() != 3 )
+            if ( addContext.getDn().size() != 3 )
             {
                 String msg = I18n.err( I18n.ERR_81 );
                 LOG.error( msg );
                 throw new LdapInvalidDnException( ResultCodeEnum.NAMING_VIOLATION, msg );
             }
             
-            String ouValue = opContext.getDn().getRdn().getNormValue().getString();
+            String ouValue = addContext.getDn().getRdn().getNormValue().getString();
             ouValue = ouValue.trim().toLowerCase();
             
             if ( ! VALID_OU_VALUES.contains( ouValue ) )
@@ -208,7 +208,7 @@ public class RegistrySynchronizerAdaptor
         }
 
         
-        String msg = I18n.err( I18n.ERR_83, opContext.getDn() );
+        String msg = I18n.err( I18n.ERR_83, addContext.getDn() );
         LOG.error( msg );
         throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM, msg );
     }
@@ -217,10 +217,10 @@ public class RegistrySynchronizerAdaptor
     /**
      * {@inheritDoc}
      */
-    public void delete( DeleteOperationContext opContext, boolean doCascadeDelete ) 
+    public void delete( DeleteOperationContext deleteContext, boolean doCascadeDelete ) 
         throws LdapException
     {
-        Entry entry = opContext.getEntry();
+        Entry entry = deleteContext.getEntry();
         
         EntryAttribute oc = entry.get( objectClassAT );
         
@@ -244,12 +244,12 @@ public class RegistrySynchronizerAdaptor
         
         if ( oc.contains( SchemaConstants.ORGANIZATIONAL_UNIT_OC ) )
         {
-            if ( opContext.getDn().size() != 3 )
+            if ( deleteContext.getDn().size() != 3 )
             {
                 throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM, I18n.err( I18n.ERR_378 ) );
             }
             
-            String ouValue = opContext.getDn().getRdn().getNormValue().getString();
+            String ouValue = deleteContext.getDn().getRdn().getNormValue().getString();
             ouValue = ouValue.trim().toLowerCase();
             
             if ( ! VALID_OU_VALUES.contains( ouValue ) )
@@ -268,14 +268,14 @@ public class RegistrySynchronizerAdaptor
     /**
      * Modify the schema
      *
      * @param opContext The context
      * @param targetEntry The modified entry
      * @param doCascadeModify Not used
      * @throws Exception If the modification failed
      */
-    public boolean modify( ModifyOperationContext opContext, Entry targetEntry, boolean doCascadeModify ) throws LdapException
+    public boolean modify( ModifyOperationContext modifyContext, Entry targetEntry, boolean doCascadeModify ) throws LdapException
     {
-        Entry entry = opContext.getEntry();
+        Entry entry = modifyContext.getEntry();
         EntryAttribute oc = entry.get( objectClassAT );
         
         for ( Value<?> value:oc )
@@ -285,14 +285,14 @@ public class RegistrySynchronizerAdaptor
             if ( objectClass2synchronizerMap.containsKey( oid ) )
             {
                 RegistrySynchronizer synchronizer = objectClass2synchronizerMap.get( oid );
-                boolean hasModification = synchronizer.modify( opContext, targetEntry, doCascadeModify );
+                boolean hasModification = synchronizer.modify( modifyContext, targetEntry, doCascadeModify );
                 return hasModification;
             }
         }
 
         if ( oc.contains( MetaSchemaConstants.META_SCHEMA_OC ) )
         {
-            boolean hasModification = schemaSynchronizer.modify( opContext, targetEntry, doCascadeModify );
+            boolean hasModification = schemaSynchronizer.modify( modifyContext, targetEntry, doCascadeModify );
             return hasModification;
         }
 
@@ -302,7 +302,7 @@ public class RegistrySynchronizerAdaptor
         }
         
         LOG.error( String.format( I18n.err( I18n.ERR_84 ), 
-            opContext.getDn(), entry, opContext.getModItems() ) );
+            modifyContext.getDn(), entry, modifyContext.getModItems() ) );
         throw new LdapUnwillingToPerformException( ResultCodeEnum.UNWILLING_TO_PERFORM );
     }
 
@@ -310,14 +310,14 @@ public class RegistrySynchronizerAdaptor
     /**
      * Rename a Schema Object.
      *
      * @param opContext The contect contaoning the rename informations
      * @param doCascadeModify unused
      * @throws Exception If the rename failed
      */
-    public void rename( RenameOperationContext opContext, boolean doCascadeModify ) 
+    public void rename( RenameOperationContext renameContext, boolean doCascadeModify ) 
         throws LdapException
     {
-        Entry originalEntry = opContext.getEntry().getOriginalEntry();
+        Entry originalEntry = renameContext.getEntry().getOriginalEntry();
         EntryAttribute oc = originalEntry.get( objectClassAT );
         
         for ( Value<?> value:oc )
@@ -327,14 +327,14 @@ public class RegistrySynchronizerAdaptor
             if ( objectClass2synchronizerMap.containsKey( oid ) )
             {
                 RegistrySynchronizer synchronizer = objectClass2synchronizerMap.get( oid );
-                synchronizer.rename( originalEntry, opContext.getNewRdn(), doCascadeModify );
+                synchronizer.rename( originalEntry, renameContext.getNewRdn(), doCascadeModify );
                 return;
             }
         }
 
         if ( oc.contains( MetaSchemaConstants.META_SCHEMA_OC ) )
         {
-            schemaSynchronizer.rename( originalEntry, opContext.getNewRdn(), doCascadeModify );
+            schemaSynchronizer.rename( originalEntry, renameContext.getNewRdn(), doCascadeModify );
             return;
         }
         
@@ -345,7 +345,7 @@ public class RegistrySynchronizerAdaptor
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.schema.SchemaChangeManager#replace(org.apache.directory.server.core.interceptor.context.MoveOperationContext, org.apache.directory.server.core.entry.Entry, boolean)
      */
-    public void move( MoveOperationContext opContext, Entry entry, boolean cascade ) throws LdapException
+    public void move( MoveOperationContext moveContext, Entry entry, boolean cascade ) throws LdapException
     {
         EntryAttribute oc = entry.get( objectClassAT );
         
@@ -356,14 +356,14 @@ public class RegistrySynchronizerAdaptor
             if ( objectClass2synchronizerMap.containsKey( oid ) )
             {
                 RegistrySynchronizer synchronizer = objectClass2synchronizerMap.get( oid );
-                synchronizer.move( opContext.getDn(), opContext.getNewSuperior(), entry, cascade );
+                synchronizer.move( moveContext.getDn(), moveContext.getNewSuperior(), entry, cascade );
                 return;
             }
         }
 
         if ( oc.contains( MetaSchemaConstants.META_SCHEMA_OC ) )
         {
-            schemaSynchronizer.move( opContext.getDn(), opContext.getNewSuperior(), entry, cascade );
+            schemaSynchronizer.move( moveContext.getDn(), moveContext.getNewSuperior(), entry, cascade );
             return;
         }
         
@@ -374,7 +374,7 @@ public class RegistrySynchronizerAdaptor
     /* (non-Javadoc)
      * @see org.apache.directory.server.core.schema.SchemaChangeManager#move(org.apache.directory.server.core.interceptor.context.MoveAndRenameOperationContext, org.apache.directory.server.core.entry.Entry, boolean)
      */
-    public void moveAndRename( MoveAndRenameOperationContext opContext, Entry entry, boolean cascade ) throws LdapException
+    public void moveAndRename( MoveAndRenameOperationContext moveAndRenameContext, Entry entry, boolean cascade ) throws LdapException
     {
         EntryAttribute oc = entry.get( objectClassAT );
         
@@ -385,16 +385,16 @@ public class RegistrySynchronizerAdaptor
             if ( objectClass2synchronizerMap.containsKey( oid ) )
             {
                 RegistrySynchronizer synchronizer = objectClass2synchronizerMap.get( oid );
-                synchronizer.moveAndRename( opContext.getDn(), opContext.getNewSuperiorDn(), opContext.getNewRdn(), 
-                    opContext.getDeleteOldRdn(), entry, cascade );
+                synchronizer.moveAndRename( moveAndRenameContext.getDn(), moveAndRenameContext.getNewSuperiorDn(), moveAndRenameContext.getNewRdn(), 
+                    moveAndRenameContext.getDeleteOldRdn(), entry, cascade );
                 return;
             }
         }
 
         if ( oc.contains( MetaSchemaConstants.META_SCHEMA_OC ) )
         {
-            schemaSynchronizer.moveAndRename( opContext.getDn(), opContext.getNewSuperiorDn(), opContext.getNewRdn(), 
-                opContext.getDeleteOldRdn(), entry, cascade );
+            schemaSynchronizer.moveAndRename( moveAndRenameContext.getDn(), moveAndRenameContext.getNewSuperiorDn(), moveAndRenameContext.getNewRdn(), 
+                moveAndRenameContext.getDeleteOldRdn(), entry, cascade );
             return;
         }
         
@@ -149,12 +149,12 @@ public class RegistrySynchronizerAdaptor
      * Add a new SchemaObject or a new Schema in the Schema partition.
      *
-     * @param opContext The Add context, containing the entry to be added
+     * @param addContext The Add context, containing the entry to be added
      * @throws Exception If the addition failed 
      */
@@ -268,14 +268,14 @@ public class RegistrySynchronizerAdaptor
      * Modify the schema
      *
-     * @param opContext The context
+     * @param modifyContext The context
      * @param targetEntry The modified entry
      * @param doCascadeModify Not used
@@ -310,14 +310,14 @@ public class RegistrySynchronizerAdaptor
      * Rename a Schema Object.
      *
-     * @param opContext The contect contaoning the rename informations
+     * @param renameContext The contect contaoning the rename informations
      * @param doCascadeModify unused
      * @throws Exception If the rename failed

Modified: directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java
URL: http://svn.apache.org/viewvc/directory/apacheds/trunk/core-api/src/main/java/org/apache/directory/server/core/schema/registries/synchronizers/SchemaSynchronizer.java?rev=955056&r1=955055&r2=955056&view=diff
==============================================================================
--- directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java (original)
+++ directory/apacheds/trunk/core-jndi/src/main/java/org/apache/directory/server/core/jndi/ServerContext.java Tue Jun 15 21:15:04 2010
@@ -162,13 +162,13 @@ public abstract class ServerContext impl
         dn = props.getProviderDn();
 
         /*
          * Need do bind operation here, and opContext returned contains the 
          * newly created session.
          */
-        BindOperationContext opContext = doBindOperation( props.getBindDn(), props.getCredentials(), 
+        BindOperationContext bindContext = doBindOperation( props.getBindDn(), props.getCredentials(), 
             props.getSaslMechanism(), props.getSaslAuthId() );
 
-        session = opContext.getSession();
+        session = bindContext.getSession();
         OperationManager operationManager = service.getOperationManager();
         
         if ( ! operationManager.hasEntry( new EntryOperationContext( session, dn ) ) )
@@ -319,10 +319,13 @@ public abstract class ServerContext impl
         
         Object typesOnlyObj = getEnvironment().get( "java.naming.ldap.typesOnly" );
         boolean typesOnly = false;
+        
         if( typesOnlyObj != null )
         {
             typesOnly = Boolean.parseBoolean( typesOnlyObj.toString() );
         }
+        
+        SearchOperationContext searchContext = null;
 
         // We have to check if it's a compare operation or a search. 
         // A compare operation has a OBJECT scope search, the filter must
@@ -333,30 +336,30 @@ public abstract class ServerContext impl
                 && ( searchControls.getReturningAttributes().length == 0 ) )
             && ( filter instanceof EqualityNode ) )
         {
-            opContext = new CompareOperationContext( session, dn, ((EqualityNode)filter).getAttribute(), ((EqualityNode)filter).getValue() );
+        	CompareOperationContext compareContext = new CompareOperationContext( session, dn, ((EqualityNode)filter).getAttribute(), ((EqualityNode)filter).getValue() );
             
             // Inject the referral handling into the operation context
-            injectReferralControl( opContext );
+            injectReferralControl( compareContext );
 
             // Call the operation
-            boolean result = operationManager.compare( (CompareOperationContext)opContext );
+            boolean result = operationManager.compare( compareContext );
 
             // setup the op context and populate with request controls
-            opContext = new SearchOperationContext( session, dn, filter,
+            searchContext = new SearchOperationContext( session, dn, filter,
                 searchControls );
-            ((SearchOperationContext)opContext).setAliasDerefMode( aliasDerefMode );
-            opContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+            searchContext.setAliasDerefMode( aliasDerefMode );
+            searchContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
             
-            ( ( SearchOperationContext ) opContext ).setTypesOnly(  typesOnly );
+            searchContext.setTypesOnly(  typesOnly );
             
             if ( result )
             {
                 Entry emptyEntry = new DefaultEntry( service.getSchemaManager(), DN.EMPTY_DN ); 
-                return new BaseEntryFilteringCursor( new SingletonCursor<Entry>( emptyEntry ), (SearchOperationContext)opContext );
+                return new BaseEntryFilteringCursor( new SingletonCursor<Entry>( emptyEntry ), searchContext );
             }
             else
             {
-                return new BaseEntryFilteringCursor( new EmptyCursor<Entry>(), (SearchOperationContext)opContext );
+                return new BaseEntryFilteringCursor( new EmptyCursor<Entry>(), searchContext );
             }
         }
         else
@@ -364,21 +367,21 @@ public abstract class ServerContext impl
             // It's a Search
             
             // setup the op context and populate with request controls
-            opContext = new SearchOperationContext( session, dn, filter, searchControls );
-            ( ( SearchOperationContext ) opContext ).setAliasDerefMode( aliasDerefMode );
-            opContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
-            ( ( SearchOperationContext ) opContext ).setTypesOnly(  typesOnly );
+        	searchContext = new SearchOperationContext( session, dn, filter, searchControls );
+        	searchContext.setAliasDerefMode( aliasDerefMode );
+        	searchContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        	searchContext.setTypesOnly(  typesOnly );
             
             // Inject the referral handling into the operation context
-            injectReferralControl( opContext );
+            injectReferralControl( searchContext );
 
             // execute search operation
-            results = operationManager.search( (SearchOperationContext)opContext );
+            results = operationManager.search( searchContext );
         }
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opContext.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( searchContext.getResponseControls() );
 
         return results;
     }
@@ -390,16 +393,16 @@ public abstract class ServerContext impl
     protected EntryFilteringCursor doListOperation( DN target ) throws Exception
     {
         // setup the op context and populate with request controls
-        ListOperationContext opCtx = new ListOperationContext( session, target );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        ListOperationContext listContext = new ListOperationContext( session, target );
+        listContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // execute list operation
         OperationManager operationManager = service.getOperationManager();
-        EntryFilteringCursor results = operationManager.list( opCtx );
+        EntryFilteringCursor results = operationManager.list( listContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( listContext.getResponseControls() );
 
         return results;
     }
@@ -407,13 +410,13 @@ public abstract class ServerContext impl
 
     protected Entry doGetRootDSEOperation( DN target ) throws Exception
     {
-        GetRootDSEOperationContext opCtx = new GetRootDSEOperationContext( session, target );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        GetRootDSEOperationContext getRootDseContext = new GetRootDSEOperationContext( session, target );
+        getRootDseContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // do not reset request controls since this is not an external 
         // operation and not do bother setting the response controls either
         OperationManager operationManager = service.getOperationManager();
-        return operationManager.getRootDSE( opCtx );
+        return operationManager.getRootDSE( getRootDseContext );
     }
 
 
@@ -423,17 +426,15 @@ public abstract class ServerContext impl
     protected Entry doLookupOperation( DN target ) throws Exception
     {
         // setup the op context and populate with request controls
-        LookupOperationContext opCtx;
-
         // execute lookup/getRootDSE operation
-        opCtx = new LookupOperationContext( session, target );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        LookupOperationContext lookupContext = new LookupOperationContext( session, target );
+        lookupContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
         OperationManager operationManager = service.getOperationManager();
-        Entry serverEntry = operationManager.lookup( opCtx );
+        Entry serverEntry = operationManager.lookup( lookupContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( lookupContext.getResponseControls() );
         return serverEntry;
     }
 
@@ -444,20 +445,18 @@ public abstract class ServerContext impl
     protected Entry doLookupOperation( DN target, String[] attrIds ) throws Exception
     {
         // setup the op context and populate with request controls
-        LookupOperationContext opCtx;
-
         // execute lookup/getRootDSE operation
-        opCtx = new LookupOperationContext( session, target, attrIds );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        LookupOperationContext lookupContext = new LookupOperationContext( session, target, attrIds );
+        lookupContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
         OperationManager operationManager = service.getOperationManager();
-        Entry serverEntry = operationManager.lookup( opCtx );
+        Entry serverEntry = operationManager.lookup( lookupContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( lookupContext.getResponseControls() );
 
         // Now remove the ObjectClass attribute if it has not been requested
-        if ( ( opCtx.getAttrsId() != null ) && ( opCtx.getAttrsId().size() != 0 ) &&
+        if ( ( lookupContext.getAttrsId() != null ) && ( lookupContext.getAttrsId().size() != 0 ) &&
             ( ( serverEntry.get( SchemaConstants.OBJECT_CLASS_AT ) != null )
                 && ( serverEntry.get( SchemaConstants.OBJECT_CLASS_AT ).size() == 0 ) ) )
         {
@@ -475,21 +474,21 @@ public abstract class ServerContext impl
         String saslAuthId ) throws Exception
     {
         // setup the op context and populate with request controls
-        BindOperationContext opCtx = new BindOperationContext( null );
-        opCtx.setDn( bindDn );
-        opCtx.setCredentials( credentials );
-        opCtx.setSaslMechanism( saslMechanism );
-        opCtx.setSaslAuthId( saslAuthId );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        BindOperationContext bindContext = new BindOperationContext( null );
+        bindContext.setDn( bindDn );
+        bindContext.setCredentials( credentials );
+        bindContext.setSaslMechanism( saslMechanism );
+        bindContext.setSaslAuthId( saslAuthId );
+        bindContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // execute bind operation
         OperationManager operationManager = service.getOperationManager();
-        operationManager.bind( opCtx );
+        operationManager.bind( bindContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
-        return opCtx;
+        responseControls = JndiUtils.toJndiControls( bindContext.getResponseControls() );
+        return bindContext;
     }
 
 
@@ -500,20 +499,20 @@ public abstract class ServerContext impl
         throws Exception
     {
         // setup the op context and populate with request controls
-        MoveAndRenameOperationContext opCtx = new MoveAndRenameOperationContext( session, oldDn, parent, new RDN(
+        MoveAndRenameOperationContext moveAndRenameContext = new MoveAndRenameOperationContext( session, oldDn, parent, new RDN(
             newRdn ), delOldDn );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        moveAndRenameContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // Inject the referral handling into the operation context
-        injectReferralControl( opCtx );
+        injectReferralControl( moveAndRenameContext );
         
         // execute moveAndRename operation
         OperationManager operationManager = service.getOperationManager();
-        operationManager.moveAndRename( opCtx );
+        operationManager.moveAndRename( moveAndRenameContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( moveAndRenameContext.getResponseControls() );
     }
 
 
@@ -523,19 +522,19 @@ public abstract class ServerContext impl
     protected void doModifyOperation( DN dn, List<Modification> modifications ) throws Exception
     {
         // setup the op context and populate with request controls
-        ModifyOperationContext opCtx = new ModifyOperationContext( session, dn, modifications );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        ModifyOperationContext modifyContext = new ModifyOperationContext( session, dn, modifications );
+        modifyContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // Inject the referral handling into the operation context
-        injectReferralControl( opCtx );
+        injectReferralControl( modifyContext );
         
         // execute modify operation
         OperationManager operationManager = service.getOperationManager();
-        operationManager.modify( opCtx );
+        operationManager.modify( modifyContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( modifyContext.getResponseControls() );
     }
 
 
@@ -545,19 +544,19 @@ public abstract class ServerContext impl
     protected void doMove( DN oldDn, DN target ) throws Exception
     {
         // setup the op context and populate with request controls
-        MoveOperationContext opCtx = new MoveOperationContext( session, oldDn, target );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        MoveOperationContext moveContext = new MoveOperationContext( session, oldDn, target );
+        moveContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // Inject the referral handling into the operation context
-        injectReferralControl( opCtx );
+        injectReferralControl( moveContext );
         
         // execute move operation
         OperationManager operationManager = service.getOperationManager();
-        operationManager.move( opCtx );
+        operationManager.move( moveContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( moveContext.getResponseControls() );
     }
 
 
@@ -567,19 +566,19 @@ public abstract class ServerContext impl
     protected void doRename( DN oldDn, RDN newRdn, boolean delOldRdn ) throws Exception
     {
         // setup the op context and populate with request controls
-        RenameOperationContext opCtx = new RenameOperationContext( session, oldDn, newRdn, delOldRdn );
-        opCtx.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
+        RenameOperationContext renameContext = new RenameOperationContext( session, oldDn, newRdn, delOldRdn );
+        renameContext.addRequestControls( JndiUtils.fromJndiControls( requestControls ) );
 
         // Inject the referral handling into the operation context
-        injectReferralControl( opCtx );
+        injectReferralControl( renameContext );
         
         // execute rename operation
         OperationManager operationManager = service.getOperationManager();
-        operationManager.rename( opCtx );
+        operationManager.rename( renameContext );
 
         // clear the request controls and set the response controls 
         requestControls = EMPTY_CONTROLS;
-        responseControls = JndiUtils.toJndiControls( opCtx.getResponseControls() );
+        responseControls = JndiUtils.toJndiControls( renameContext.getResponseControls() );
     }
@@ -162,13 +162,13 @@ public abstract class ServerContext impl
 
         /*
-         * Need do bind operation here, and opContext returned contains the 
+         * Need do bind operation here, and bindContext returned contains the 
          * newly created session.
          */